#ifndef NT2_INCLUDE_FUNCTIONS_ELLPK_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ELLPK_HPP_INCLUDED

#include <nt2/elliptic/include/functions/ellpk.hpp>

#endif
